/******************************************************************************
 The computer software and associated documentation called DOMAK hereinafter
 referred to as the WORK which is more particularly identified and described in
 Appendix A of the file LICENSE.  Conditions and restrictions for use of
 this package are also in this file.

 This file was written by Asim S. Siddiqui


 All use of the WORK must cite:
 Siddiqui, A. S. and Barton, G. J., "Continuous and Discontinuous Domains: An
 Algorithm for the Automatic Generation of Reliable Protein Domain Definitions" 
 PROTEIN SCIENCE, 4:872-884 (1995).
*****************************************************************************/

/* Name
 *    asd_check_utils.h
 * Author
 *    Asim Siddiqui
 */

#include <asd_structs.h>

#ifndef HAVE_ASD_CHECK_UTILS_H
#define HAVE_ASD_CHECK_UTILS_H

int
asd_check_seg_a(Asd_Contact_List *c_list, bool_t ss_only, char *ss,
                Asd_Domain *d_to_split, int s1_sn, int s1_min_len,
                int start_chain, int type);

int
asd_check_seg_1(Asd_Contact_List *c_list, bool_t ss_only, char *ss,
                Asd_Domain *d_to_split, int s1_sn, int s1_en);

#endif /*HAVE_ASD_CHECK_UTILS_H*/
